/// Copyright Thomas Nagy 2007
/// License: QPL

#include <KIcon>
#include <QtDebug>
#include <QTreeView>
#include <QGridLayout>
#include <KPushButton>
#include <QLineEdit>
#include <QSizePolicy>

#include  "Jelzpn.h"
#include  "Egyenes.h"
#include  "AblaK.h"
#include  "con.h"
#include  "tslabels.h"

/*!
 * @praise Vishnu
 */
egytr::egytr(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
<%
	kidlgz=megkap;
	QGridLayout *tqrost=new QGridLayout();
	jlnrdz=new egykl(this,megkap);

	KPushButton *irnyjl=new KPushButton(this);
	irnyjl->setIcon(KIcon(ts_255));
	irnyjl->setIconSize(QSize(22,22));
	irnyjl->setFlat(1);
	irnyjl->setFocusPolicy(Qt::NoFocus);
	irnyjl->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
	irnyjl->setMaximumSize(QSize(27,27));
	irnyjl->resize(25,25);
	irnyjl->setAutoDefault(0);
	QLineEdit *adelk=new QLineEdit(this);

	connect(irnyjl,SIGNAL(clicked(bool)),adelk,SLOT(clear()));
	connect(adelk,SIGNAL(textChanged(const QString&)),jlnrdz,SLOT(vnl(const QString&)));

	tqrost->addWidget(irnyjl,0,0);
	tqrost->addWidget(adelk,0,1);
	tqrost->addWidget(jlnrdz,1,0,1,2);

	setLayout(tqrost);
%>

void egytr::kelt(const zagv& adelk)
<%
	jlnrdz->kelt(adelk);
%>

#ifdef WAF
#include "Egyenes.moc"
#endif

